pub struct NalParser { /* private fields */ }Expand description
Splits an incrementally arriving bitstream into NAL units.
This searches for 001 marks in a byte stream, and deals with cross-boundary checks when
a frame is partially read.
Implementations
Sourceimpl NalParser
impl NalParser
Sourcepub fn next(&mut self) -> Option<Vec<u8>>
pub fn next(&mut self) -> Option<Vec<u8>>
Tries to retrieve the next NAL unit, if present.
After feeding new data you should keep calling this method until it returns None.
Sourcepub fn feed(&mut self, buffer: impl AsRef<[u8]>)
pub fn feed(&mut self, buffer: impl AsRef<[u8]>)
Feeds more data to the processor.
After calling this method, there may be between 0 to M new NAL units present, which you can query with Self::next().